@@ -71,6 +71,11 @@
 //// This will enable additional features, such as use of initialiser lists
 #endif
 
+#if (__cplusplus >= 201103L) || defined(__GXX_EXPERIMENTAL_CXX0X__)
+  #undef  ARMA_USE_CXX11
+  #define ARMA_USE_CXX11
+#endif
+
 #if !defined(ARMA_USE_U64S64)
 // #define ARMA_USE_U64S64
 //// Uncomment the above line if you require u64 and s64 integer types.
@@ -80,8 +85,15 @@
 
 #if !defined(ARMA_USE_HDF5)
 // #define ARMA_USE_HDF5
-//// Uncomment the above line if you want the ability to save and load matrices stored in the HDF5 format;
-//// the hdf5.h header file must be available on your system and you will need to link with the hdf5 library (eg. -lhdf5)
+//// Uncomment the above line to allow the ability to save and load matrices stored in HDF5 format;
+//// the hdf5.h header file must be available on your system,
+//// and you will need to link with the hdf5 library (eg. -lhdf5)
+#endif
+
+// #define ARMA_USE_HDF5_ALT
+#if defined(ARMA_USE_HDF5_ALT) && defined(ARMA_USE_WRAPPER)
+  #undef  ARMA_USE_HDF5
+  #define ARMA_USE_HDF5
 #endif
 
 #if !defined(ARMA_MAT_PREALLOC)
@@ -158,6 +170,10 @@
   #endif
 #endif
 
+#if defined(ARMA_DONT_USE_CXX11_RNG)
+  #undef ARMA_USE_CXX11_RNG
+#endif
+
 #if defined(ARMA_DONT_USE_HDF5)
   #undef ARMA_USE_HDF5
 #endif
